@@ -486,6 +486,11 @@ public:
      */
     void lock(void);
 
+    /**
+     * Timed lock request.
+     */
+    bool lock(timeout_t timeout);
+
     /**
      * Release or decrease locking.
      */
@@ -1475,6 +1480,12 @@ protected:
      */
     Thread(size_t stack = 0);
 
+    /**
+     * Map thread for get method.  This should be called from start of the
+     * run() method of a derived class.
+     */
+    void map(void);
+
 public:
     /**
      * Set thread priority without disrupting scheduling if possible.
@@ -1496,6 +1507,14 @@ public:
      */
     static void sleep(timeout_t timeout);
 
+    /**
+     * Get mapped thread object.  This returns the mapped base class of the
+     * thread object of the current executing context.  You will need to
+     * cast to the correct derived class to access derived thread-specific
+     * storage.  If the current thread context is not mapped NULL is returned.
+     */
+    static Thread *get(void);
+
     /**
      * Abstract interface for thread context run method.
      */
@@ -1546,13 +1565,7 @@ public:
      * Get current thread id.
      * @return thread id.
      */
-#ifdef  __PTH__
-    inline static pthread_t self(void)
-        {return pth_self();};
-#else
-    inline static pthread_t self(void)
-        {return pthread_self();};
-#endif
+    static pthread_t self(void);
 };
 
 /**
@@ -1567,14 +1580,13 @@ public:
  */
 class __EXPORT JoinableThread : protected Thread
 {
-private:
+protected:
 #ifdef  _MSWINDOWS_
     HANDLE joining;
 #else
     volatile bool running;
 #endif
 
-protected:
     /**
      * Create a joinable thread with a known context stack size.
      * @param size of stack for thread context or 0 for default.
